@@ -6,6 +6,7 @@ check_suggests <- function(package) {
 }
 
 # -------------------------------------------------------------------------
+
 # new_bare_tibble() is a small wrapper around tibble::new_tibble() that also
 # forces extra attributes to be dropped through the use of
 # vctrs::new_data_frame(). In the future, new_tibble() might have an option
@@ -16,11 +17,13 @@ new_bare_tibble <- function(x) {
   x <- vctrs::new_data_frame(x)
   tibble::new_tibble(x, nrow = nrow(x))
 }
+
 # -------------------------------------------------------------------------
 
-
 get_weekday_name <- function(x) {
-  wdays <- weekdays(as.Date(grates::as_yearweek(as.Date("2020-01-01"), firstday = 1L)) + 0:6)
+  wdays <- weekdays(
+    as.Date(grates::as_yearweek(as.Date("2020-01-01"), firstday = 1L)) + 0:6
+  )
   wdays <- setNames(1:7, wdays)
   names(wdays[x])
 }
